@@ -66,6 +66,10 @@ class Window():
         self.application = application
         self.settings = Gio.Settings(schema_id="org.x.thingy")
 
+        # Dark mode manager
+        # keep a reference to it (otherwise it gets randomly garbage collected)
+        self.dark_mode_manager = XApp.DarkModeManager.new(prefer_dark_mode=False)
+
         self.recent_manager = Gtk.RecentManager()
         self.favorites_manager = XApp.Favorites.get_default()
 
@@ -126,7 +130,7 @@ class Window():
         self.app_model = Gtk.ListStore(object, str, str) # APP_INFO, APP_NAME, ID
         for app in SUPPORTED_APPS:
             for app_info in Gio.AppInfo.get_all():
-                if app_info.get_filename() == f"/usr/share/applications/{app}.desktop":
+                if os.path.basename(app_info.get_filename()) == f"{app}.desktop":
                     self.app_model.append([app_info, app_info.get_display_name(), app])
                     break
 
@@ -163,7 +167,7 @@ class Window():
         dlg.set_program_name("thingy")
         dlg.set_comments(_("Library"))
         try:
-            h = open('/usr/share/licenses/common/GPL/license.txt', encoding="utf-8")
+            h = open('/usr/share/licenses/spdx/GPL-3.0-or-later.txt', encoding="utf-8")
             s = h.readlines()
             gpl = ""
             for line in s:
@@ -173,7 +177,7 @@ class Window():
         except Exception as e:
             print (e)
 
-        dlg.set_version("1.0.5")
+        dlg.set_version("1.2.0")
         dlg.set_icon_name("thingy")
         dlg.set_logo_icon_name("thingy")
         dlg.set_website("https://www.github.com/linuxmint/thingy")
@@ -230,7 +234,8 @@ class Window():
     @idle
     def add_document_to_library(self, uri, app_id, mark_as_favorite):
         # Ignore duplicates
-        if uri in self.documents:
+        real_path = os.path.realpath(uri)
+        if real_path in self.documents:
             return
         f = Gio.File.new_for_uri(uri)
         # Ignore non-existing paths
@@ -240,7 +245,7 @@ class Window():
         # Ignore hidden mimetypes
         if app_id in HIDDEN_MIMETYPES and info.get_content_type() in HIDDEN_MIMETYPES[app_id]:
             return
-        self.documents.append(uri)
+        self.documents.append(real_path)
         name = info.get_display_name()
         thumbnail_path = info.get_attribute_byte_string ("thumbnail::path")
         icon = info.get_attribute_object("standard::icon")
@@ -261,17 +266,18 @@ class Window():
         label.set_halign(Gtk.Align.CENTER)
 
         progress_tracked = False
-        if (num_pages != None and current_page != None):
+        if num_pages is not None and current_page is not None:
             num_pages = int(num_pages)
-            current_page = int(current_page)
-            if current_page > 0:
-                progress = float(current_page) / float(num_pages)
-                bar = Gtk.ProgressBar()
-                bar.set_fraction(progress)
-                bar.set_margin_start(50)
-                bar.set_margin_end(50)
-                box.pack_end(bar, False, False, 0)
-                progress_tracked = True
+            if num_pages > 4:
+                current_page = int(current_page)
+                if current_page > 0:
+                    progress = float(current_page) / float(num_pages - 1)
+                    bar = Gtk.ProgressBar()
+                    bar.set_fraction(progress)
+                    bar.set_margin_start(50)
+                    bar.set_margin_end(50)
+                    box.pack_end(bar, False, False, 0)
+                    progress_tracked = True
 
         if not progress_tracked:
             box.pack_end(Gtk.Label(), False, False, 0)
@@ -280,16 +286,16 @@ class Window():
 
         overlay = Gtk.Overlay()
 
-        if thumbnail_path != None:
-            image = Gtk.Image.new_from_file(thumbnail_path)
+        if thumbnail_path is not None:
+            pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(thumbnail_path, 198, 198)
         else:
             extension = os.path.splitext(uri)[1][1:].strip().lower()
             if os.path.exists("/usr/share/thingy/doc-%s.svg" % extension):
-                pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/thingy/doc-%s.svg" % extension, 198, 256)
+                pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/thingy/doc-%s.svg" % extension, 198, 198)
             else:
-                pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/thingy/doc.svg", 198, 256)
-            image = Gtk.Image.new_from_pixbuf(pixbuf)
+                pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/thingy/doc.svg", 198, 198)
 
+        image = Gtk.Image.new_from_pixbuf(pixbuf)
         image.get_style_context().add_class("thingy-image")
 
         if mark_as_favorite:
